@@ -1,4 +1,6 @@
+import os
 import time
+import subprocess  # nosec
 import logging
 
 from sqlalchemy import create_engine, text, inspect
@@ -16,6 +18,7 @@ from vwsfriend.agents.state_agent import StateAgent
 from vwsfriend.agents.climatization_agent import ClimatizationAgent
 from vwsfriend.agents.refuel_agent import RefuelAgent
 from vwsfriend.agents.trip_agent import TripAgent
+from vwsfriend.agents.weconnect_error_agent import WeconnectErrorAgent
 from vwsfriend.agents.abrp.abrp_agent import ABRPAgent
 from vwsfriend.model.base import Base
 from vwsfriend.model import Vehicle
@@ -30,6 +33,19 @@ class AgentConnector():
         self.agents = {}
 
         if withDB:
+            if os.path.isfile(configDir + '/provisioning/database.vwsfrienddbbackup'):
+                try:
+                    with open(configDir + '/provisioning/database.vwsfrienddbbackup', mode='rb') as file:
+                        LOG.info('Trying to restore database backup')
+                        process = subprocess.run(['pg_restore', '--clean', '--if-exists', '--format', 'c', '--dbname', dbUrl], stdin=file,  # nosec
+                                                 stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=False)
+                        if process.returncode != 0:
+                            LOG.error('pg_restore returned %d: %s', process.returncode, process.stderr.decode('ascii'))
+                        else:
+                            LOG.info('It looks like the backup could be successfully restored')
+                finally:
+                    os.remove(configDir + '/provisioning/database.vwsfrienddbbackup')
+
             engine = create_engine(dbUrl, pool_pre_ping=True)
             self.session = Session(engine)
 
@@ -61,6 +77,10 @@ class AgentConnector():
 
         weConnect.addObserver(self.onEnable, AddressableLeaf.ObserverEvent.ENABLED, onUpdateComplete=True)
 
+        self.agents["none"] = []
+        if self.withDB:
+            self.agents["none"].append(WeconnectErrorAgent(self.session, weConnect))
+
     def onEnable(self, element, flags):
         if (flags & AddressableLeaf.ObserverEvent.ENABLED) and isinstance(element, vehicle.Vehicle):
             if element.vin not in self.agents:
