@@ -200,14 +200,14 @@ class ChargeAgent():
                     self.chargingSession.location = locationFromLatLon(self.session, parkingPosition.latitude.value, parkingPosition.longitude.value)
                 if self.chargingSession.charger is None:
                     self.chargingSession.charger = chargerFromLatLon(weConnect=self.vehicle.weConnectVehicle.weConnect, session=self.session,
-                                                                     latitude=parkingPosition.latitude.value, longitude=parkingPosition.longitude.value,
-                                                                     searchRadius=100)
+                                                                     latitude=round(parkingPosition.latitude.value, 4),
+                                                                     longitude=round(parkingPosition.longitude.value, 4), searchRadius=100)
 
     def updateMileage(self):
-        if 'maintenanceStatus' in self.vehicle.weConnectVehicle.statuses:
-            maintenanceStatus = self.vehicle.weConnectVehicle.statuses['maintenanceStatus']
-            if self.chargingSession is not None and maintenanceStatus.mileage_km.enabled and maintenanceStatus.mileage_km.value is not None:
-                self.chargingSession.mileage_km = maintenanceStatus.mileage_km.value
+        if 'odometerMeasurement' in self.vehicle.weConnectVehicle.statuses:
+            odometerMeasurement = self.vehicle.weConnectVehicle.statuses['odometerMeasurement']
+            if self.chargingSession is not None and odometerMeasurement.odometer.enabled and odometerMeasurement.odometer.value is not None:
+                self.chargingSession.mileage_km = odometerMeasurement.odometer.value
 
     def commit(self):
         pass
